# -*- coding: utf-8 -*-
from setuphelpers import *
import glob
import os

app_name = "PrusaSlicer"
editor_dir = makepath(programfiles, "PrusaSlicer")
app_dir = makepath(editor_dir, "PrusaSlicer")
app_path = ""  # Initialisation vide, sera mise à jour dynamiquement
audit_version = False

def get_installed_version(app_path):
    return get_file_properties(app_path).get("FileVersion", "")

def install():
    # Declaring local variables
    zip_files = glob.glob("PrusaSlicer-*.zip")
    if not zip_files:
        print("No PrusaSlicer ZIP file found.")
        return
    
    zip_name = zip_files[0]
    unzipped_dir = "PrusaSlicer"

    # Installing software
    killalltasks(ensure_list(control.impacted_process))
    if isdir(app_dir) and force:
        remove_tree(app_dir)
    mkdirs(app_dir)
    print(f"Extracting: {zip_name} to: {unzipped_dir}")
    unzip(zip_name, unzipped_dir)
    
    # Finding the extracted directory with version
    extracted_version_dirs = glob.glob(os.path.join(unzipped_dir, "PrusaSlicer-*"))
    if not extracted_version_dirs:
        print("No versioned PrusaSlicer directory found after extraction.")
        return

    extracted_version_dir = extracted_version_dirs[0]  # Assuming one version directory is present
    print(f'Copy PrusaSlicer from {extracted_version_dir} to {app_dir}')
    copytree2(extracted_version_dir, app_dir, onreplace=default_overwrite)

    global app_path
    app_path = makepath(app_dir, "prusa-slicer.exe")

    # Creating custom shortcuts
    create_desktop_shortcut(app_name, target=app_path)
    create_programs_menu_shortcut(app_name, target=app_path)

def audit():
    # Auditing software
    audit_status = "OK"
    installed_version = get_installed_version(app_path)
    if Version(installed_version) < Version(control.get_software_version()) and audit_version:
        print(f"{app_name} is installed in version ({installed_version}) instead of ({control.get_software_version()})")
        audit_status = "WARNING"
    elif isdir(app_dir) and not dir_is_empty(app_dir):
        print(f"{app_name} ({installed_version}) is installed")
        audit_status = "OK"
    else:
        print(f"{app_name} is not installed")
        audit_status = "ERROR"
    return audit_status

def uninstall():
    # Uninstalling software
    killalltasks(ensure_list(control.impacted_process))
    if isdir(app_dir):
        remove_tree(app_dir)
    if dir_is_empty(editor_dir):
        remove_tree(editor_dir)

    # Removing shortcuts
    remove_desktop_shortcut(app_name)
    remove_programs_menu_shortcut(app_name)
